@@ -8,10 +8,12 @@ use Object::InsideOut;
 use XML::LibXML;
 use Readonly;
 use Scalar::Util qw/ weaken /;
+use Date::Parse;
+use Time::Piece;
 
 use WWW::Ohloh::API::StackEntry;
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
 my @ohloh_of : Field : Arg(ohloh);
 my @request_url_of : Field : Arg(request_url) : Get( request_url );
@@ -26,7 +28,7 @@ my @api_fields = qw/
   account
   /;
 
-__PACKAGE__->create_field( '%' . $_, ":Set(_set_$_)", ":Get($_)" )
+__PACKAGE__->create_field( '@' . $_, ":Set(_set_$_)", ":Get($_)" )
   for qw/ id updated_at project_count account_id /;
 
 my @stack_entries_of : Field;
@@ -39,11 +41,15 @@ sub _init : Init {
 
     my $dom = $xml_of[$$self] or return;
 
-    for my $f (qw/ id updated_at project_count account_id /) {
+    for my $f (qw/ id project_count account_id /) {
         my $method = "_set_$f";
         $self->$method( $dom->findvalue("$f/text()") );
     }
 
+    $self->_set_updated_at(
+        Time::Piece->new( str2time( $dom->findvalue("updated_at/text()") ) )
+    );
+
     if ( my ($account_xml) = $dom->findnodes('account[1]') ) {
         $account_of[$$self] = WWW::Ohloh::API::Account->new(
             ohloh => $ohloh_of[$$self],
@@ -124,6 +130,20 @@ sub set_account : Private( WWW::Ohloh::API::Account ) {
 'end of WWW::Ohloh::API::Stack';
 __END__
 
+=begin test
+
+use lib 't';
+use FakeOhloh;
+use WWW::Ohloh::API::Stack;
+
+my $ohloh = Fake::Ohloh->new;
+
+$ohloh->stash( 'yadah', 'stack.xml' );
+
+my $thingy = $ohloh->get_account_stack( 123 );
+
+=end test
+
 =head1 NAME
 
 WWW::Ohloh::API::Stack - a collection of projects used by a person 
@@ -148,33 +168,50 @@ by a person.
 
 =head1 METHODS 
 
+=for test ignore
+
 =head2 API Data Accessors
 
-=head2 id
+=for test
+
+=head3 id
 
 Returns the unique id for the stack.
 
-=head2 updated_at
+=for test
+    is $result[0] => 21420, 'id()';
+
+=head3 updated_at
 
 Returns the most recent time at which any projects were added to
-or removed from this stack.
+or removed from this stack as a L<Time::Piece> object.
 
-=head2 project_count
+=for test
+    isa_ok $result[0], 'Time::Piece';
+    is $result[0], 'Mon Mar 17 13:09:16 2008', 'updated_at()';
+
+=head3 project_count
 
 Returns the number of projects in the stack.
 
-=head2 stack_entries
+=head3 stack_entries
 
-Returns an array of the entries contained by the stack (see
-L<WWW::Ohloh::API::StackEntry>).
+Returns a list of the entries contained by the stack as
+L<WWW::Ohloh::API::StackEntry> objects.
 
-=head2 account_id
+=for test
+    isa_ok $_, 'WWW::Ohloh::API::StackEntry' for @result;
+    is @result => 35, '35 stack entries';
+
+=head3 account_id
 
 Returns the id of the account owning the stack.
 
-=head2 account
+=for test
+    $ohloh->stash( 'account', 'account.xml' );
+    my $retrieve = 1;
 
-    $account = $stack->account( $retrieve );
+=head3 account( I<$retrieve> )
 
 Returns the account associated 
 to the stack as a L<WWW::Ohloh::API::Account> object.
@@ -183,15 +220,27 @@ If the account information was not present at the object's
 creation time, it will be queried from the ohloh server,
 unless I<$retrieve> is defined and set to false.
 
+=for test
+    isa_ok $result[0], 'WWW::Ohloh::API::Account';
+    # querying it again shouldn't cause a fetch
+    is $thingy->account => $result[0], 'querying again';
+
+=for test ignore
 
 =head2 Other Methods
 
+=for test
+
 =head3 as_xml
 
-Return the stack as an XML string.  
+Returns the stack as an XML string.  
 Note that this is not the same xml document as returned
 by the Ohloh server. 
 
+=for test
+    use XML::LibXML;
+    ok( XML::LibXML->new->parse_string( $result[0] ), 'as_xml' );
+
 =head1 SEE ALSO
 
 =over
@@ -212,7 +261,7 @@ Ohloh Account API reference: http://www.ohloh.net/api/reference/stack
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 0.2.0
+This document describes WWW::Ohloh::API version 0.3.0
 
 =head1 BUGS AND LIMITATIONS
 
